Overview: Why pynsitu?
===================

Oceanographic In situ data analysis
-----------------------------

This library gathers tools useful for the analysis of in situ Oceanographic observations, typically collected during experimental campaigns.
These observations are organized around platforms/deployments and may be time-varying, georeferenced, include core tracer variables (e.g. temperature and salinity).

We utilize the pandas_ and xarray_ as standard data containers.

.. _pandas: https://pandas.pydata.org
.. _xarray: https://docs.xarray.dev/en/stable/
